# nakdimon-ort

[`nakdimon`](https://github.com/elazarg/nakdimon) diacritizer with onnxruntime

## Setup

```console
pip install nakdimon-ort
```

You also need [`nakdimon.onnx`](https://github.com/thewh1teagle/nakdimon-ort/releases/download/v0.1.0/nakdimon.onnx). Please see [examples](examples).

## Examples

See [examples](examples)

## Credits

Thanks for [elazarg](https://github.com/elazarg) for creating [nakdimon](https://github.com/elazarg/nakdimon) model!
